@@ -501,21 +501,14 @@ let draw_calendar (iface : interface_state_t)
                |Str.Text d ->
                   let day = pred (int_of_string d) in
                   if succ day = sel_tm.Unix.tm_mday then begin
-                     (* highlight selected day *)
-                     if today_tm.Unix.tm_year = sel_tm.Unix.tm_year &&
-                        today_tm.Unix.tm_mon = sel_tm.Unix.tm_mon &&
-                        succ day = today_tm.Unix.tm_mday then
-                        (* if it's also today's date, use boldface *)
-                           wattron iface.scr.calendar_win A.bold
-                     else
-                        ();
-                     Rcfile.color_on iface.scr.calendar_win Rcfile.Calendar_selection;
-                     assert (waddstr iface.scr.calendar_win d);
-                     Rcfile.color_off iface.scr.calendar_win Rcfile.Calendar_selection;
-                     wattroff iface.scr.calendar_win A.bold
-                  end else if today_tm.Unix.tm_year = sel_tm.Unix.tm_year &&
-                              today_tm.Unix.tm_mon = sel_tm.Unix.tm_mon &&
-                              succ day = today_tm.Unix.tm_mday then begin
+                     (* highlight selected day in reverse video *)
+                     wattron iface.scr.calendar_win A.reverse;
+                     (* assert (waddstr iface.scr.calendar_win d); *)
+                  end else
+                     ();
+                  if today_tm.Unix.tm_year = sel_tm.Unix.tm_year &&
+                     today_tm.Unix.tm_mon = sel_tm.Unix.tm_mon &&
+                     succ day = today_tm.Unix.tm_mday then begin
                      (* highlight today's date *)
                      Rcfile.color_on iface.scr.calendar_win Rcfile.Calendar_today;
                      wattron iface.scr.calendar_win A.bold;
@@ -584,20 +577,8 @@ let draw_calendar (iface : interface_state_t)
 let draw_untimed (iface : interface_state_t) reminders =
    let lineinfo = Array.make iface.scr.uw_lines None in
    let blank = String.make iface.scr.uw_cols ' ' in
-   let curr_ts = Unix.localtime (timestamp_of_line iface iface.left_selection) in
-   let temp1 = {
-      curr_ts with Unix.tm_sec  = 0;
-                   Unix.tm_min  = 0;
-                   Unix.tm_hour = 0
-   } in
-   let temp2 = {
-      curr_ts with Unix.tm_sec  = 0;
-                   Unix.tm_min  = 0;
-                   Unix.tm_hour = 0;
-                   Unix.tm_mday = succ curr_ts.Unix.tm_mday 
-   } in
-   let (day_start_ts, _) = Unix.mktime temp1 in
-   let (day_end_ts, _)   = Unix.mktime temp2 in
+   let curr_ts = timestamp_of_line iface iface.left_selection in
+   let today_reminders = Remind.get_untimed_reminders_for_day reminders curr_ts in
    werase iface.scr.untimed_win;
    let acs = get_acs_codes () in
    Rcfile.color_on iface.scr.untimed_win Rcfile.Right_divider;
@@ -606,13 +587,11 @@ let draw_untimed (iface : interface_state_t) reminders =
    mvwhline iface.scr.untimed_win 0 1 acs.Acs.hline (pred iface.scr.uw_cols);
    mvwvline iface.scr.untimed_win 1 0 acs.Acs.vline (pred iface.scr.uw_lines);
    Rcfile.color_off iface.scr.untimed_win Rcfile.Right_divider;
+   if not !Rcfile.untimed_bold then
+      wattroff iface.scr.untimed_win A.bold
+   else
+      ();
    Rcfile.color_on iface.scr.untimed_win Rcfile.Untimed_reminder;
-   (* Filter the reminders list to find only those corresponding to the
-    * selected day *)
-   let is_current rem =
-      rem.ur_start >= day_start_ts && rem.ur_start < day_end_ts
-   in
-   let today_reminders = List.filter is_current reminders in
    (* make sure the cursor doesn't unexpectedly disappear *)
    let iface =
       if iface.selected_side = Right && 
