@@ -1,5 +1,5 @@
 (*  Wyrd -- a curses-based front-end for Remind
- *  Copyright (C) 2005, 2006 Paul Pelzl
+ *  Copyright (C) 2005, 2006, 2007 Paul Pelzl
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, Version 2,
@@ -34,7 +34,7 @@ let usage =
 in
 let show_version () =
    print_endline ("Wyrd v" ^ Version.version);
-   print_endline "Copyright (C) 2005, 2006 Paul Pelzl";
+   print_endline "Copyright (C) 2005, 2006, 2007 Paul Pelzl";
    print_endline "";
    print_endline "Wyrd comes with ABSOLUTELY NO WARRANTY.  This is Free Software,";
    print_endline "and you are welcome to redistribute it under certain conditions;";
@@ -42,13 +42,40 @@ let show_version () =
    print_endline "";
    exit 0;
 in
+let event_desc_opt = ref None in
+let do_quick_event event_desc =
+   event_desc_opt := Some event_desc
+in
 let parse_definition = [
-   ("--version", Arg.Unit show_version, " Display version information and exit")
+   ("--version", Arg.Unit show_version, " Display version information and exit");
+   ("-a", Arg.String do_quick_event, " Add given event to reminders file and exit");
+   ("--add", Arg.String do_quick_event, " Add given event to reminders file and exit");
 ] in
-Arg.parse (Arg.align parse_definition) parse_anonymous_opt usage;;
+Arg.parse (Arg.align parse_definition) parse_anonymous_opt usage;
+
+(* After parsing all arguments, handle quick reminders.  We have to
+ * do it in this order so that the filename (anonymous option) gets
+ * set prior to creating the new event. *)
+begin match !event_desc_opt with
+| Some event_desc ->
+   begin try
+      let _ = Interface_main.append_quick_event event_desc !Rcfile.reminders_file in
+      exit 0
+   with Time_lang.Event_parse_error s ->
+      Printf.fprintf stderr "Error: %s\n" s;
+      exit 1
+   end
+| None ->
+   ()
+end;;
 
 
 let initialize_screen () =
+   if Install.wide_ncurses then
+      (* ncursesw doesn't render non-ASCII without the setlocale() call *)
+      let _ = Locale.setlocale Locale.LC_ALL "" in ()
+   else
+      ();
    let std = initscr () in
    begin try
       assert (start_color ());
